coherence.extern.simple_plugin (module) — Cohen3 0.8.0 documentation

# coherence.extern.simple_plugin (module)

## Simple Plugin

Real simple plugin system meant as a replacement when setuptools/pkg_resources are not available.

class `Plugin`

  Bases: `object`

  a new style class that betrays all its sub-classes

class `Reception`(plugin_path=None, log=None)

  Bases: `object`

  Singleton class which holds information about known plugins.

  Currently a singleton, and even a class, seems to be overkill for this, but maybe we’ll add some more functionality later.

  Initializes the class and checks in if a path is provided.

  `_instance_` = None
  `__init__`(plugin_path=None, log=None)

    Initializes the class and checks in if a path is provided.

  `checkin`(plugin_path)

    Import all valid files from plugin_path.

  `guestlist`(plugin_class=<class 'coherence.extern.simple_plugin.Plugin'>)

    Returns a list of all Plugin subclasses.